.. _intro-examples:

=================
Moose示例
=================

了解怎样使用Moose的最快的办法就是通过实际项目开始。为此，我们提供了为三个标注项目编写的app作为参考，以帮助用户快速上手使用Moose。该Moose项目 datatang_ 在 `http://git.datatang.com/xiaoyang/datatang`_，包含的三个项目分别涉及音频标注项目导出、图片标注项目上传及导出、视频标注项目的抽取上传和导出。可以在README.md中了解到更多项目相关的信息。

如果你对git比较熟悉，可以checkout下来相应代码并且试着运行。如果不是，你也可以通过点击 这里_ 下载。


.. _datatang: http://git.datatang.com/xiaoyang/datatang
.. _http://git.datatang.com/xiaoyang/datatang: http://git.datatang.com/xiaoyang/datatang
.. _这里: http://git.datatang.com/xiaoyang/datatang/archive/master.zip
